import 'package:witsystem_core/error/entity/ErrorType.dart';
import 'package:witsystem_core/error/entity/WitsystemError.dart';
import 'package:witsystem_core/generated/l10n.dart';

///网络请求的所有异常

class NetError {
  static WitsystemError error(int code) {
    return _errMap[code] ?? _unknown;
  }

  static final WitsystemError _unknown = WitsystemError(
      code: -9999, type: ErrorType.net, error: S.current.unknown); //未知错误

  static final Map<int, WitsystemError> _errMap = {
    0: WitsystemError(code: 0, type: ErrorType.net, error: S.current.success),
    -1: WitsystemError(code: -1, type: ErrorType.net, error: S.current.fail),
    10001: WitsystemError(code: 10001, type: ErrorType.net, error: S.current.platform_info_error),
    10002: WitsystemError(code: 10002, type: ErrorType.net, error: S.current.platform_no_pay),
    10003: WitsystemError(code: 10003, type: ErrorType.net, error: S.current.platform_no_secret),
    10004: WitsystemError(code: 10004, type: ErrorType.net, error: S.current.platform_trilateral_fail),
    10005: WitsystemError(code: 10005, type: ErrorType.net, error: S.current.platform_trilateral_error_info),
    10006: WitsystemError(code: 10006, type: ErrorType.net, error: S.current.analysis_user_info_fail),


    11001: WitsystemError(code: 11001, type: ErrorType.net, error: S.current.order_exception),
    11002: WitsystemError(code: 11002, type: ErrorType.net, error: S.current.order_refund_exception),
    11003: WitsystemError(code: 11003, type: ErrorType.net, error: S.current.order_refund_order_no_info),
    11004: WitsystemError(code: 11004, type: ErrorType.net, error: S.current.order_sign_exception),
    11005: WitsystemError(code: 11005, type: ErrorType.net, error: S.current.order_no_refund_info),
    11006: WitsystemError(code: 11006, type: ErrorType.net, error: S.current.order_over_time),
    11007: WitsystemError(code: 11007, type: ErrorType.net, error: S.current.order_no_auth),
    11008: WitsystemError(code: 11008, type: ErrorType.net, error: S.current.order_applications),
    11009: WitsystemError(code: 11009, type: ErrorType.net, error: S.current.order_not_device),
    11010: WitsystemError(code: 11010, type: ErrorType.net, error: S.current.order_not_info),
    11011: WitsystemError(code: 11011, type: ErrorType.net, error: S.current.order_created_fail),
    11012: WitsystemError(code: 11012, type: ErrorType.net, error: S.current.order_collection_info_fail),
    11013: WitsystemError(code: 11013, type: ErrorType.net, error: S.current.order_not_room),
    11014: WitsystemError(code: 11014, type: ErrorType.net, error: S.current.order_not_other_extra),
    11015: WitsystemError(code: 11015, type: ErrorType.net, error: S.current.order_status_not_ask),
    11016: WitsystemError(code: 11016, type: ErrorType.net, error: S.current.order_share_exception),
    11017: WitsystemError(code: 11017, type: ErrorType.net, error: S.current.order_not_share),
    11018: WitsystemError(code: 11018, type: ErrorType.net, error: S.current.order_not_support_share),
    11019: WitsystemError(code: 11019, type: ErrorType.net, error: S.current.order_repeat_handle),


    20001: WitsystemError(code: 20001, type: ErrorType.net, error: S.current.token_error),
    20002: WitsystemError(code: 20002, type: ErrorType.net, error: S.current.auth_insufficient),
    20003: WitsystemError(code: 20003, type: ErrorType.net, error: S.current.user_exist),
    20004: WitsystemError(code: 20004, type: ErrorType.net, error: S.current.login_password_error),
    20005: WitsystemError(code: 20005, type: ErrorType.net, error: S.current.login_code_error),
    20006: WitsystemError(code: 20006, type: ErrorType.net, error: S.current.user_password_notnull),
    20007: WitsystemError(code: 20007, type: ErrorType.net, error: S.current.inhere_password_error),
    20008: WitsystemError(code: 20008, type: ErrorType.net, error: S.current.user_same_password),
    20009: WitsystemError(code: 20009, type: ErrorType.net, error: S.current.password_length_error),
    20010: WitsystemError(code: 20010, type: ErrorType.net, error: S.current.relationship_error),
    20011: WitsystemError(code: 20011, type: ErrorType.net, error: S.current.no_changes),
    20012: WitsystemError(code: 20012, type: ErrorType.net, error: S.current.user_pay_account_number),
    20013: WitsystemError(code: 20013, type: ErrorType.net, error: S.current.permissions_frozen),
    20014: WitsystemError(code: 20014, type: ErrorType.net, error: S.current.no_wx_login),



    30001: WitsystemError(code: 30001, type: ErrorType.net, error: S.current.param_not_complete),
    30002: WitsystemError(code: 30002, type: ErrorType.net, error: S.current.param_error),
    30003: WitsystemError(code: 30003, type: ErrorType.net, error: S.current.system_error),
    30004: WitsystemError(code: 30004, type: ErrorType.net, error: S.current.system_auth),
    30005: WitsystemError(code: 30005, type: ErrorType.net, error: S.current.system_processing),
    30006: WitsystemError(code: 30006, type: ErrorType.net, error: S.current.decryption_fail),
    30007: WitsystemError(code: 30007, type: ErrorType.net, error: S.current.ciphertext_format_error),
    30008: WitsystemError(code: 30008, type: ErrorType.net, error: S.current.illegal_login),
    30009: WitsystemError(code: 30009, type: ErrorType.net, error: S.current.login_device_time_error),


    40001: WitsystemError(code: 40001, type: ErrorType.net, error: S.current.device_relations),
    40002: WitsystemError(code: 40002, type: ErrorType.net, error: S.current.device_auth_time_error),
    40003: WitsystemError(code: 40003, type: ErrorType.net, error: S.current.device_user_auth_insufficient),
    40004: WitsystemError(code: 40004, type: ErrorType.net, error: S.current.device_on_line),
    40005: WitsystemError(code: 40005, type: ErrorType.net, error: S.current.device_ask_timeout),
    40006: WitsystemError(code: 40006, type: ErrorType.net, error: S.current.device_already_join),
    40007: WitsystemError(code:40007, type: ErrorType.net, error:S.current.device_issue_cmd_timeout),
    40009: WitsystemError(code:40009, type: ErrorType.net, error:S.current.device_auth_error),
    40010: WitsystemError(code:40010, type: ErrorType.net, error:S.current.device_already_place),
    40011: WitsystemError(code:40011, type: ErrorType.net, error:S.current.no_bind_relay),
    40012: WitsystemError(code:40012, type: ErrorType.net, error:S.current.device_accept_auth_error),
    40013: WitsystemError(code:40013, type: ErrorType.net, error:S.current.device_accept_grade_error),
    40014: WitsystemError(code:40014, type: ErrorType.net, error:S.current.device_auth_high_level),
    40015: WitsystemError(code:40015, type: ErrorType.net, error:S.current.device_auth_high_grade),
    40016: WitsystemError(code:40016, type: ErrorType.net, error:S.current.device_qr_code_auth_info_error),
    40017: WitsystemError(code:40017, type: ErrorType.net, error:S.current.device_share_qr_code_close),
    40018: WitsystemError(code:40018, type: ErrorType.net, error:S.current.device_join_project),
    40019: WitsystemError(code:40019, type: ErrorType.net, error:S.current.device_join_projectlog),
    40020: WitsystemError(code:40020, type: ErrorType.net, error:S.current.device_join_room),
    40021: WitsystemError(code:40021, type: ErrorType.net, error:S.current.device_before_time),
    40022: WitsystemError(code:40022, type: ErrorType.net, error:S.current.device_overdue),
    40023: WitsystemError(code:40023, type: ErrorType.net, error:S.current.device_no_oneself),
    40024: WitsystemError(code:40024, type: ErrorType.net, error:S.current.device_no_user_auth),
    40025: WitsystemError(code:40025, type: ErrorType.net, error:S.current.device_auth_grade_same),
    40026: WitsystemError(code:40026, type: ErrorType.net, error:S.current.device_auth_same_grade_min),
    40027: WitsystemError(code:40027, type: ErrorType.net, error:S.current.device_freeze),
    40028: WitsystemError(code:40028, type: ErrorType.net, error:S.current.device_money_exception),
    40029: WitsystemError(code:40029, type: ErrorType.net, error:S.current.device_info_fail),
    40030: WitsystemError(code:40030, type: ErrorType.net, error:S.current.device_latest_version),
    40031: WitsystemError(code:40031, type: ErrorType.net, error:S.current.device_model_exist),
    40032: WitsystemError(code:40032, type: ErrorType.net, error:S.current.device_firmware_file_null),
    40033: WitsystemError(code:40033, type: ErrorType.net, error:S.current.device_model_not_exist),
    40034: WitsystemError(code:40034, type: ErrorType.net, error:S.current.device_command_exception),



    50001: WitsystemError(code:50001, type: ErrorType.net, error:S.current.sign_error),
    50002: WitsystemError(code:50002, type: ErrorType.net, error:S.current.sign_exception),
    50003: WitsystemError(code:50003, type: ErrorType.net, error:S.current.sign_time_stamp_error),


    60001: WitsystemError(code:60001, type: ErrorType.net, error:S.current.room_no),
    60002: WitsystemError(code:60002, type: ErrorType.net, error:S.current.room_auth_error),
    60003: WitsystemError(code:60003, type: ErrorType.net, error:S.current.lack_room_auth),
    60004: WitsystemError(code:60004, type: ErrorType.net, error:S.current.not_manager_room_auth),
    60005: WitsystemError(code:60005, type: ErrorType.net, error:S.current.no_room_info),
    60006: WitsystemError(code:60006, type: ErrorType.net, error:S.current.room_state_error),
    60007: WitsystemError(code:60007, type: ErrorType.net, error:S.current.not_user_room_auth),
    60008: WitsystemError(code:60008, type: ErrorType.net, error:S.current.room_pact_not_completed),
    60009: WitsystemError(code:60009, type: ErrorType.net, error:S.current.room_atypism_pact),
    60010: WitsystemError(code:60010, type: ErrorType.net, error:S.current.no_query_info),
    60011: WitsystemError(code:60011, type: ErrorType.net, error:S.current.device_binding),
    60013: WitsystemError(code:60013, type: ErrorType.net, error:S.current.room_incorrect_validity_period),
    60014: WitsystemError(code:60014, type: ErrorType.net, error:S.current.outstanding_initial_payment),
    60015: WitsystemError(code:60015, type: ErrorType.net, error:S.current.room_upper_occupancy_limit),
    60016: WitsystemError(code:60016, type: ErrorType.net, error:S.current.room_other_order_delete_fail),
    60017: WitsystemError(code:60017, type: ErrorType.net, error:S.current.room_extra_no_have),
    60018: WitsystemError(code:60018, type: ErrorType.net, error:S.current.room_pact_finish),
    60019: WitsystemError(code:60019, type: ErrorType.net, error:S.current.room_extra_order_on_finish),
    60020: WitsystemError(code:60020, type: ErrorType.net, error:S.current.room_extra_and_room),
    60021: WitsystemError(code:60021, type: ErrorType.net, error:S.current.room_first_money),
    60022: WitsystemError(code:60022, type: ErrorType.net, error:S.current.room_arrearage_first_money),
    60023: WitsystemError(code:60023, type: ErrorType.net, error:S.current.room_rent_out_money),
    60024: WitsystemError(code:60024, type: ErrorType.net, error:S.current.room_extra_due),
    60025: WitsystemError(code:60025, type: ErrorType.net, error:S.current.room_change_room_fail),
    60026: WitsystemError(code:60026, type: ErrorType.net, error:S.current.room_relation_auth_error),
    60027: WitsystemError(code:60027, type: ErrorType.net, error:S.current.room_arrearage_error)



  };
}
